@@ -5,12 +5,12 @@ with '::Role', -Ee;
 
 sub ee_events {qw(srv_accept srv_error)}
 
-sub srv_handle_accept ($self, $sock) : Override {
+sub srv_handle_accept ($self, $sock) : Over {
   $self->emit(srv_accept => $sock);
   $sock;
 }
 
-sub srv_handle_error ($self, $conn, $err) : Override {
+sub srv_handle_error ($self, $conn, $err) : Over {
   Evo::Net::Srv::Role::srv_handle_error($self, $conn, $err);
   $self->emit(srv_error => $conn, $err);
 }
@@ -29,7 +29,7 @@ Evo::Net::Srv
 
 =head1 VERSION
 
-version 0.0225
+version 0.0226
 
 =head1 SYNOPSYS
 
