@@ -145,7 +145,7 @@ sub d_traverse($self) {
           my $x;
           eval { $x = $h->($v); 1 } ? $cur->d_resolve_continue($x) : $cur->d_reject_continue($@);
         };
-        &loop_postpone($sub);    # 2.2.4, call async
+        $self->postpone($sub);    # 2.2.4, call async
         next;
       }
 
@@ -157,6 +157,10 @@ sub d_traverse($self) {
 
 }
 
+sub postpone ($self, $fn) {
+  &loop_postpone($fn);
+}
+
 1;
 
 __END__
@@ -171,7 +175,7 @@ Evo::Promise::Class
 
 =head1 VERSION
 
-version 0.0225
+version 0.0226
 
 =head1 AUTHOR
 
